]> git.sesse.net Git - movit/blobdiff - effect.h
Rename RGBATriplet to RGBATuple, to avoid silliness.
[movit] / effect.h
index 43849dfa5cdddd61035a58a528061f7045276ead..9d4f247632449cbb2cccaf44000d75343b4b147c 100644 (file)
--- a/effect.h
+++ b/effect.h
@@ -1,5 +1,5 @@
-#ifndef _EFFECT_H
-#define _EFFECT_H 1
+#ifndef _MOVIT_EFFECT_H
+#define _MOVIT_EFFECT_H 1
 
 // Effect is the base class for every effect. It basically represents a single
 // GLSL function, with an optional set of user-settable parameters.
 // effect instance; use the macro PREFIX() around your identifiers to
 // automatically prepend that prefix.
 
+#include <GL/glew.h>
+#include <assert.h>
+#include <stddef.h>
 #include <map>
 #include <string>
-#include <vector>
-
-#include <assert.h>
-
-#include <Eigen/Core>
 
-#include <GL/glew.h>
-#include "util.h"
+#include "defs.h"
 
 class EffectChain;
 class Node;
@@ -41,23 +38,13 @@ struct RGBTriplet {
 };
 
 // Can alias on a float[4].
-struct RGBATriplet {
-       RGBATriplet(float r, float g, float b, float a)
+struct RGBATuple {
+       RGBATuple(float r, float g, float b, float a)
                : r(r), g(g), b(b), a(a) {}
 
        float r, g, b, a;
 };
 
-// Convenience functions that deal with prepending the prefix.
-GLint get_uniform_location(GLuint glsl_program_num, const std::string &prefix, const std::string &key);
-void set_uniform_int(GLuint glsl_program_num, const std::string &prefix, const std::string &key, int value);
-void set_uniform_float(GLuint glsl_program_num, const std::string &prefix, const std::string &key, float value);
-void set_uniform_vec2(GLuint glsl_program_num, const std::string &prefix, const std::string &key, const float *values);
-void set_uniform_vec3(GLuint glsl_program_num, const std::string &prefix, const std::string &key, const float *values);
-void set_uniform_vec4(GLuint glsl_program_num, const std::string &prefix, const std::string &key, const float *values);
-void set_uniform_vec4_array(GLuint glsl_program_num, const std::string &prefix, const std::string &key, const float *values, size_t num_values);
-void set_uniform_mat3(GLuint glsl_program_num, const std::string &prefix, const std::string &key, const Eigen::Matrix3d &matrix);
-
 class Effect {
 public:
        virtual ~Effect() {}
@@ -99,7 +86,8 @@ public:
        // This is the most natural format for processing, and the default in
        // most of Movit (just like linear light is).
        //
// If you set INPUT_AND_OUTPUT_PREMULTIPLIED_ALPHA, all of your inputs
        // (if any) are guaranteed to also be in premultiplied alpha.
        // Otherwise, you can get postmultiplied or premultiplied alpha;
        // you won't know. If you have multiple inputs, you will get the same
@@ -121,9 +109,19 @@ public:
                // If you set this, you should also set needs_linear_light().
                INPUT_AND_OUTPUT_PREMULTIPLIED_ALPHA,
 
-               // Keeps the type of alpha unchanged from input to output.
-               // Usually appropriate if you process all color channels
-               // in a linear fashion, and do not change alpha.
+               // Like INPUT_AND_OUTPUT_PREMULTIPLIED_ALPHA, but also guarantees
+               // that if you get blank alpha in, you also keep blank alpha out.
+               // This is a somewhat weaker guarantee than DONT_CARE_ALPHA_TYPE,
+               // but is still useful in many situations, and appropriate when
+               // e.g. you don't touch alpha at all.
+               //
+               // Does not make sense for inputs.
+               INPUT_PREMULTIPLIED_ALPHA_KEEP_BLANK,
+
+               // Keeps the type of alpha (premultiplied, postmultiplied, blank)
+               // unchanged from input to output. Usually appropriate if you
+               // process all color channels in a linear fashion, do not change
+               // alpha, and do not produce any new pixels thare have alpha != 1.0.
                //
                // Does not make sense for inputs.
                DONT_CARE_ALPHA_TYPE,
@@ -286,4 +284,4 @@ private:
        std::map<std::string, Texture1D> params_tex_1d;
 };
 
-#endif // !defined(_EFFECT_H)
+#endif // !defined(_MOVIT_EFFECT_H)
@@ -99,7 +86,8 @@ public:
        // most of Movit (just like linear light is).
        //
-       // If you set INPUT_AND_OUTPUT_PREMULTIPLIED_ALPHA, all of your inputs
+       // If you set INPUT_AND_OUTPUT_PREMULTIPLIED_ALPHA or
+       // INPUT_PREMULTIPLIED_ALPHA_KEEP_BLANK, all of your inputs
        // (if any) are guaranteed to also be in premultiplied alpha.
        // Otherwise, you can get postmultiplied or premultiplied alpha;